=========
Alligator
=========

Simple offline task queues. For Python.

"See you later, alligator."


Guide
=====

.. toctree::
   :maxdepth: 2

   installing
   tutorial
   bestpractices
   extending

   contributing
   security


API Reference
=============

.. toctree::
   :glob:

   reference/*


Release Notes
=============

.. toctree::
   :maxdepth: 1

   releasenotes/0.8.0
   releasenotes/0.7.1
   releasenotes/0.7.0
   releasenotes/0.6.0
   releasenotes/0.5.1
   releasenotes/0.5.0


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

